"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Observable {
    constructor(collect = true, collect_intervall = 100) {
        this.collect = collect;
        this.collect_intervall = collect_intervall;
        this.subscriber = [];
        this.events = [];
        this.timeout = undefined;
    }
    /**
     * Creates Public API with subscribe and unsubscribe
     *
     * @returns {object}
     */
    getPublicApi() {
        return {
            /**
             * Subscribe to Observable
             * @param {function} callback
             */
            subscribe: (callback, one = false) => {
                let oldcb = this.subscriber.find(e => e.callback === callback);
                if (oldcb)
                    oldcb.one = one;
                else
                    this.subscriber.push({ callback, one });
            },
            /**
            * Subscribe fron Observable
            * @param {function} callback
            */
            unsubscribe: (callback) => {
                let idx = this.subscriber.findIndex(e => e.callback === callback);
                if (idx >= 0) {
                    this.subscriber.splice(idx, 1);
                }
            }
        };
    }
    /**
     * Sends data to all subscribers
     * @param data data to be sent
     */
    send(data) {
        if (!this.collect)
            this.subscriber.forEach(e => e.callback([data]));
        else {
            this.events.push(data);
            if (!this.timeout) {
                this.timeout = setTimeout(() => {
                    this.subscriber.forEach(cb => {
                        if (cb.one)
                            this.events.forEach(e => cb.callback([e]));
                        else
                            cb.callback(this.events);
                    });
                    this.timeout = undefined;
                }, this.collect_intervall);
            }
        }
    }
}
exports.default = Observable;
//# sourceMappingURL=observable.js.map